etianen-cms
===========

A collection of Django extensions that add content-management facilities to Django projects.


Overview
--------

The term *Content Management System* means different things to different people.
Rather than attempting to create a single monolithic solution to fit all needs, this project uses
a modular approach, allowing you to pick the parts you need, and extend it where necessary.

**Core features:**

*   Publication controls with online preview.
*   Pre-configured WYSIWYG editor widgets.
*   Hierarchal page management with no depth limit.
*   Image and file management, with easy embedding via WYSIWYG editors or pure model fields.

**Optional additional features:**

*   Version control and rollback (via [django-reversion](https://github.com/etianen/django-reversion)).
*   Automatic SEO-friendly redirect management (via [django-historylinks](https://github.com/etianen/django-historylinks)).
*   Full-text search with relevance ranking (via [django-watson](https://github.com/etianen/django-watson)).
*   Internal / external links in menus (via bundled [Links app](https://github.com/etianen/cms/wiki/links-app)).
*   Simple blog managment (via bundled [News app](https://github.com/etianen/cms/wiki/news-app)).


Documentation
-------------

Please read the [Getting Started][] guide for more information.

[Getting Started]: https://github.com/etianen/cms/wiki
    "Getting started with etianen-cms"
    
Download instructions, bug reporting and links to full documentation can be
found at the [main project website][].

[main project website]: http://github.com/etianen/cms
    "etianen-cms on GitHub"

You can keep up to date with the latest announcements by joining the
[etianen-cms discussion group][].

[etianen-cms discussion group]: http://groups.google.com/group/etianen-cms
    "etianen-cms Google Group"


More information
----------------

Dave Hall is a freelance web developer, based in Cambridge, UK. You can usually
find him on the Internet in a number of different places:

*   [Website](http://www.etianen.com/ "Dave Hall's homepage")
*   [Twitter](http://twitter.com/etianen "Dave Hall on Twitter")
*   [Google Profile](http://www.google.com/profiles/david.etianen "Dave Hall's Google profile")